csc411_rpegio
A collection functions to handle rpeg data i/o. Intended for use in URI’s CSC 411 class.
Functions
- input_
rpeg_ data - Reads and parses rpeg data from a file, or stdin if no file path is given.
- output_
rpeg_ data - Outputs rpeg data to stdout.
- output_
rpeg_ data_ debug - Outputs rpeg data to stdout in a human-readable, debug form. This is only intended to be used for debugging and testing.